# DV SDK
# -------
#
# cmake configuration for DV SDK
#
# IMPORTED Targets
# ^^^^^^^^^^^^^^^^
#
# ``dv::sdk`` the shared library
#
# Result VARIABLES
# ^^^^^^^^^^^^^^^^
#
# ``dv_FOUND`` ``TRUE`` if the library and all required components were found. If ``FALSE`` do not use the library.
# ``dv_VERSION`` version as "MM.mm.pp[-rev]" ``dv_VERSION_(MAJOR|MINOR|PATCH)`` the version components
#

# dv-processing base classes.
FIND_PACKAGE(dv-processing 1.7.2 REQUIRED)

# Boost support for extra components. dv-processing will already have set this up.
FIND_PACKAGE(Boost 1.76 REQUIRED COMPONENTS nowide filesystem)

# Actual package import.

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was dv-config.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib64/cmake/dv" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

INCLUDE(${PACKAGE_PREFIX_DIR}/lib64/cmake/dv/dv-targets.cmake)

CHECK_REQUIRED_COMPONENTS(dv)

# Cross-compile support
IF(NOT USER_LOCAL_PREFIX)
	SET(USER_LOCAL_PREFIX ${CMAKE_INSTALL_PREFIX})
ENDIF()

# Define module installation paths.
SET(DV_MODULES_DIR ${CMAKE_INSTALL_DATAROOTDIR}/dv/modules)
MESSAGE(STATUS "Filesystem modules installation directory is: ${CMAKE_INSTALL_PREFIX}/${DV_MODULES_DIR}")

ADD_DEFINITIONS(-DDV_MODULES_DIR=${USER_LOCAL_PREFIX}/${DV_MODULES_DIR})
MESSAGE(STATUS "Actual modules installation directory is: ${USER_LOCAL_PREFIX}/${DV_MODULES_DIR}")

# Set full RPATH, modules are libraries for DV.
SET(CMAKE_INSTALL_RPATH ${USER_LOCAL_PREFIX}/${DV_MODULES_DIR})

# Set DV_LIBRARIES to just dv::sdk (backwards compatibility).
SET(DV_LIBRARIES dv::sdk)
MESSAGE(STATUS "DV_LIBRARIES set to: ${DV_LIBRARIES}")
